summaryrefslogtreecommitdiffstats
path: root/kdgantt
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-07 20:29:44 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-07 20:29:44 -0600
commita66f0a09b66888c0d080fc47651210b644b39114 (patch)
tree817d01cecfb618d62f65929a984455ec1bbf94f0 /kdgantt
parent8fdee58df91aa54d53e3e0147f20df18dce3a06e (diff)
downloadtdepim-a66f0a09b66888c0d080fc47651210b644b39114.tar.gz
tdepim-a66f0a09b66888c0d080fc47651210b644b39114.zip
Rename kwin to twin (part 1 of 2)
Diffstat (limited to 'kdgantt')
-rw-r--r--kdgantt/KDGanttView.cpp26
-rw-r--r--kdgantt/KDGanttView.h8
-rw-r--r--kdgantt/KDGanttViewSubwidgets.cpp10
-rw-r--r--kdgantt/KDGanttViewSubwidgets.h8
4 files changed, 26 insertions, 26 deletions
diff --git a/kdgantt/KDGanttView.h b/kdgantt/KDGanttView.h
index 264b609c1..70b423218 100644
--- a/kdgantt/KDGanttView.h
+++ b/kdgantt/KDGanttView.h
@@ -102,7 +102,7 @@ class KDGanttView : public KDGanttMinimizeSplitter
TQ_PROPERTY( bool showTimeTablePopupMenu READ showTimeTablePopupMenu WRITE setShowTimeTablePopupMenu )
TQ_PROPERTY( bool headerVisible READ headerVisible WRITE setHeaderVisible )
TQ_PROPERTY( bool showLegendButton READ showLegendButton WRITE setShowLegendButton )
- TQ_PROPERTY( bool legendIsDockwindow READ legendIsDockwindow WRITE setLegendIsDockwindow )
+ TQ_PROPERTY( bool legendIsDoctwindow READ legendIsDoctwindow WRITE setLegendIsDoctwindow )
TQ_PROPERTY( bool displayEmptyTasksAsLine READ displayEmptyTasksAsLine WRITE setDisplayEmptyTasksAsLine )
TQ_PROPERTY( TQBrush noInformationBrush READ noInformationBrush WRITE setNoInformationBrush )
TQ_PROPERTY( bool dragEnabled READ dragEnabled WRITE setDragEnabled )
@@ -132,9 +132,9 @@ public:
int ganttMaximumWidth() const;
void setShowLegend( bool show );
bool showLegend() const;
- void setLegendIsDockwindow( bool dock );
- bool legendIsDockwindow( ) const;
- TQDockWindow* legendDockwindow( ) const;
+ void setLegendIsDoctwindow( bool dock );
+ bool legendIsDoctwindow( ) const;
+ TQDockWindow* legendDoctwindow( ) const;
void setShowListView( bool show );
bool showListView() const;
void setEditorEnabled( bool enable );
diff --git a/kdgantt/KDGanttViewSubwidgets.cpp b/kdgantt/KDGanttViewSubwidgets.cpp
index c6a326a3c..9f76bea6e 100644
--- a/kdgantt/KDGanttViewSubwidgets.cpp
+++ b/kdgantt/KDGanttViewSubwidgets.cpp
@@ -2553,11 +2553,11 @@ KDLegendWidget:: KDLegendWidget( TQWidget* parent,
clearLegend();
showMe ( false );
}
-void KDLegendWidget::setAsDockwindow( bool dockwin )
+void KDLegendWidget::setAsDoctwindow( bool doctwin )
{
- if ( (dock == 0 && !dockwin) || ( dock && dockwin ) )
+ if ( (dock == 0 && !doctwin) || ( dock && doctwin ) )
return;
- if ( dockwin )
+ if ( doctwin )
{
setMaximizedWidget( 0 );
showMe ( false );
@@ -2594,7 +2594,7 @@ void KDLegendWidget::setAsDockwindow( bool dockwin )
}
-bool KDLegendWidget::asDockwindow( )
+bool KDLegendWidget::asDoctwindow( )
{
if ( dock )
return true;
@@ -2602,7 +2602,7 @@ bool KDLegendWidget::asDockwindow( )
}
-TQDockWindow* KDLegendWidget::dockwindow( )
+TQDockWindow* KDLegendWidget::doctwindow( )
{
return dock;
}
diff --git a/kdgantt/KDGanttViewSubwidgets.h b/kdgantt/KDGanttViewSubwidgets.h
index b044c10ec..cbccbb109 100644
--- a/kdgantt/KDGanttViewSubwidgets.h
+++ b/kdgantt/KDGanttViewSubwidgets.h
@@ -53,7 +53,7 @@
#include <tqlabel.h>
#include <tqbrush.h>
#include <tqvbox.h>
-#include <tqdockwindow.h>
+#include <tqdoctwindow.h>
#include <tqtimer.h>
#include "KDGanttView.h"
@@ -341,9 +341,9 @@ public:
void clearLegend();
void setFont( TQFont );
void drawToPainter( TQPainter *p );
- void setAsDockwindow( bool dockwin );
- bool asDockwindow();
- TQDockWindow* dockwindow();
+ void setAsDoctwindow( bool doctwin );
+ bool asDoctwindow();
+ TQDockWindow* doctwindow();
TQSize legendSize();
TQSize legendSizeHint();
private:
diff --git a/kdgantt/KDGanttView.cpp b/kdgantt/KDGanttView.cpp
index 303ca8651..0af98043b 100644
--- a/kdgantt/KDGanttView.cpp
+++ b/kdgantt/KDGanttView.cpp
@@ -606,12 +606,12 @@ void KDGanttView::slotHeaderSizeChanged()
Specifies whether the legend should be shown as a dock window or not.
\param show if true, show legend as a dock window
- \sa showLegend(), legendIsDockwindow(), legendDockwindow()
-*/void KDGanttView::setLegendIsDockwindow( bool show )
+ \sa showLegend(), legendIsDoctwindow(), legendDoctwindow()
+*/void KDGanttView::setLegendIsDoctwindow( bool show )
{
- bool isdock = myLegend->asDockwindow();
+ bool isdock = myLegend->asDoctwindow();
if ( show != isdock ) {
- myLegend->setAsDockwindow(show);
+ myLegend->setAsDoctwindow(show);
// legend is cleared - reinit legend with list
legendItem* li;
for ( li = myLegendItems->first(); li; li = myLegendItems->next() ) {
@@ -625,10 +625,10 @@ void KDGanttView::slotHeaderSizeChanged()
Returns whether the legend is shown as a dock window
\return true if the legend is shown as a dock window
- \sa setShowLegend(), setLegendIsDockwindow(), legendDockwindow()
-*/bool KDGanttView::legendIsDockwindow() const
+ \sa setShowLegend(), setLegendIsDoctwindow(), legendDoctwindow()
+*/bool KDGanttView::legendIsDoctwindow() const
{
- return myLegend->asDockwindow();
+ return myLegend->asDoctwindow();
}
@@ -637,16 +637,16 @@ void KDGanttView::slotHeaderSizeChanged()
DO NOT DELETE THIS POINTER!
If the legend is not a dock window, 0 is returned
To set the legend as a dock window, call
- KDGanttView::setLegendIsDockwindow( true );
+ KDGanttView::setLegendIsDoctwindow( true );
\return the pointer to the legend dock window
0 is returned, if the legend is no dock window
DO NOT DELETE THIS POINTER!
- \sa setShowLegend(), setLegendIsDockwindow(),legendIsDockwindow()
+ \sa setShowLegend(), setLegendIsDoctwindow(),legendIsDoctwindow()
*/
-TQDockWindow* KDGanttView::legendDockwindow() const
+TQDockWindow* KDGanttView::legendDoctwindow() const
{
- return myLegend->dockwindow();
+ return myLegend->doctwindow();
}
@@ -2529,7 +2529,7 @@ bool KDGanttView::loadXML( const TQDomDocument& doc )
} else if( tagName == "LegendIsDockWindow" ) {
bool value;
if( KDGanttXML::readBoolNode( element, value ) )
- setLegendIsDockwindow( value );
+ setLegendIsDoctwindow( value );
} else if( tagName == "ShowListView" ) {
bool value;
if( KDGanttXML::readBoolNode( element, value ) )
@@ -3285,7 +3285,7 @@ TQDomDocument KDGanttView::saveXML( bool withPI ) const
// the LegendIsDockWindow element
KDGanttXML::createBoolNode( doc, docRoot, "LegendIsDockWindow",
- legendIsDockwindow() );
+ legendIsDoctwindow() );
// the ShowListView element
KDGanttXML::createBoolNode( doc, docRoot, "ShowListView", showListView() );